==> chrome-devtools-kotlin-0.14.3-sources.jar: org/hildan/chrome/devtools/domains/tracing/events/TracingEvents.kt <==
@file:Suppress("RedundantVisibilityModifier", "DEPRECATION", "EXPERIMENTAL_API_USAGE")

package org.hildan.chrome.devtools.domains.tracing.events

import kotlin.Boolean
import kotlin.Double
import kotlin.Suppress
import kotlin.collections.List
import kotlinx.serialization.Serializable
import kotlinx.serialization.json.JsonElement
import org.hildan.chrome.devtools.domains.io.StreamHandle
import org.hildan.chrome.devtools.domains.tracing.StreamCompression
import org.hildan.chrome.devtools.domains.tracing.StreamFormat

@Serializable
public sealed class TracingEvent {
  /**
   *
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#event-bufferUsage)
   */
  @Serializable
  public data class BufferUsageEvent(
    /**
     * A number in range [0..1] that indicates the used size of event buffer as a fraction of its
     * total size.
     */
    public val percentFull: Double? = null,
    /**
     * An approximate number of events in the trace log.
     */
    public val eventCount: Double? = null,
    /**
     * A number in range [0..1] that indicates the used size of event buffer as a fraction of its
     * total size.
     */
    public val value: Double? = null
  ) : TracingEvent()

  /**
   * Contains an bucket of collected trace events. When tracing is stopped collected events will be
   * send as a sequence of dataCollected events followed by tracingComplete event.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#event-dataCollected)
   */
  @Serializable
  public data class DataCollectedEvent(
    public val value: List<JsonElement>
  ) : TracingEvent()

  /**
   * Signals that tracing is stopped and there is no trace buffers pending flush, all data were
   * delivered via dataCollected events.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#event-tracingComplete)
   */
  @Serializable
  public data class TracingCompleteEvent(
    /**
     * Indicates whether some trace data is known to have been lost, e.g. because the trace ring
     * buffer wrapped around.
     */
    public val dataLossOccurred: Boolean,
    /**
     * A handle of the stream that holds resulting trace data.
     */
    public val stream: StreamHandle? = null,
    /**
     * Trace data format of returned stream.
     */
    public val traceFormat: StreamFormat? = null,
    /**
     * Compression format of returned stream.
     */
    public val streamCompression: StreamCompression? = null
  ) : TracingEvent()
}

==> chrome-devtools-kotlin-4.2.0-sources.jar: org/hildan/chrome/devtools/domains/tracing/events/TracingEvents.kt <==
@file:Suppress("RedundantVisibilityModifier", "DEPRECATION", "EXPERIMENTAL_API_USAGE")

package org.hildan.chrome.devtools.domains.tracing.events

import kotlin.Boolean
import kotlin.Double
import kotlin.Suppress
import kotlin.collections.List
import kotlinx.serialization.Serializable
import kotlinx.serialization.json.JsonObject
import org.hildan.chrome.devtools.domains.io.StreamHandle
import org.hildan.chrome.devtools.domains.tracing.StreamCompression
import org.hildan.chrome.devtools.domains.tracing.StreamFormat

@Serializable
public sealed class TracingEvent {
  /**
   *
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#event-bufferUsage)
   */
  @Serializable
  public data class BufferUsage(
    /**
     * A number in range [0..1] that indicates the used size of event buffer as a fraction of its
     * total size.
     */
    public val percentFull: Double? = null,
    /**
     * An approximate number of events in the trace log.
     */
    public val eventCount: Double? = null,
    /**
     * A number in range [0..1] that indicates the used size of event buffer as a fraction of its
     * total size.
     */
    public val `value`: Double? = null,
  ) : TracingEvent()

  /**
   * Contains an bucket of collected trace events. When tracing is stopped collected events will be
   * send as a sequence of dataCollected events followed by tracingComplete event.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#event-dataCollected)
   */
  @Serializable
  public data class DataCollected(
    public val `value`: List<JsonObject>,
  ) : TracingEvent()

  /**
   * Signals that tracing is stopped and there is no trace buffers pending flush, all data were
   * delivered via dataCollected events.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Tracing/#event-tracingComplete)
   */
  @Serializable
  public data class TracingComplete(
    /**
     * Indicates whether some trace data is known to have been lost, e.g. because the trace ring
     * buffer wrapped around.
     */
    public val dataLossOccurred: Boolean,
    /**
     * A handle of the stream that holds resulting trace data.
     */
    public val stream: StreamHandle? = null,
    /**
     * Trace data format of returned stream.
     */
    public val traceFormat: StreamFormat? = null,
    /**
     * Compression format of returned stream.
     */
    public val streamCompression: StreamCompression? = null,
  ) : TracingEvent()
}
